import 'package:audioplayers/audioplayers.dart';
import 'package:flutter/material.dart';
import 'package:nowa_runtime/nowa_runtime.dart';

class AudioPlayerController extends ChangeNotifier {
  AudioPlayerController({required this.path, required this.type}) {
    _audioPlayer.onPlayerStateChanged.listen((state) {
      isPlaying = state == PlayerState.playing;
      notifyListeners();
    });

    _audioPlayer.onDurationChanged.listen((newDuration) {
      duration = newDuration;
      notifyListeners();
    });

    _audioPlayer.onPositionChanged.listen((newPosition) {
      position = newPosition;
      notifyListeners();
    });
  }

  final AudioPlayer _audioPlayer = AudioPlayer();

  // attributes

  String path;
  FileSourceType type;

  // variables

  Duration duration = Duration.zero;
  Duration position = Duration.zero;
  bool isPlaying = false;

  // methods

  Future<void> play() async {
    if (type == FileSourceType.network) {
      await _audioPlayer.play(UrlSource(path));
    } else if (type == FileSourceType.asset) {
      await _audioPlayer.play(AssetSource(path));
    }
  }

  Future<void> pause() async => await _audioPlayer.pause();

  Future<void> stop() async => await _audioPlayer.stop();

  Future<void> resume() async => await _audioPlayer.resume();

  Future<void> seek(double value) async {
    final newPosition = Duration(seconds: value.toInt());
    await _audioPlayer.seek(newPosition);
  }

  // Getters

  String get getDurationHHMMSSFormat {
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    String twoDigitHours = twoDigits(duration.inHours.abs());
    String twoDigitMinutes = twoDigits(duration.inMinutes.remainder(60).abs());
    String twoDigitSeconds = twoDigits(duration.inSeconds.remainder(60).abs());
    return "$twoDigitHours:$twoDigitMinutes:$twoDigitSeconds";
  }

  String get getDurationMMSSFormat {
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    int totalMinutes = duration.inMinutes.abs(); // Absolute value for consistency
    String twoDigitMinutes = twoDigits(totalMinutes);
    String twoDigitSeconds = twoDigits(duration.inSeconds.remainder(60).abs());
    return "$twoDigitMinutes:$twoDigitSeconds";
  }

  String get getDurationHHMMFormat {
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    String twoDigitHours = twoDigits(duration.inHours.abs());
    String twoDigitMinutes = twoDigits(duration.inMinutes.remainder(60).abs());
    return "$twoDigitHours:$twoDigitMinutes";
  }

  String get getPositionHHMMSSFormat {
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    String twoDigitHours = twoDigits(position.inHours.abs());
    String twoDigitMinutes = twoDigits(position.inMinutes.remainder(60).abs());
    String twoDigitSeconds = twoDigits(position.inSeconds.remainder(60).abs());
    return "$twoDigitHours:$twoDigitMinutes:$twoDigitSeconds";
  }

  String get getPositionMMSSFormat {
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    int totalMinutes = position.inMinutes.abs(); // Absolute value for consistency
    String twoDigitMinutes = twoDigits(totalMinutes);
    String twoDigitSeconds = twoDigits(position.inSeconds.remainder(60).abs());
    return "$twoDigitMinutes:$twoDigitSeconds";
  }

  String get getPositionHHMMFormat {
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    String twoDigitHours = twoDigits(position.inHours.abs());
    String twoDigitMinutes = twoDigits(position.inMinutes.remainder(60).abs());
    return "$twoDigitHours:$twoDigitMinutes";
  }

  @override
  void dispose() {
    super.dispose();
    _audioPlayer.dispose();
  }
}
