import 'package:flutter/material.dart';

/// Widget that updates whenever the change notifier notifies
/// Use instead of [AnimatedBuilder] when the notifier can be nullable
class NotifierBuilder extends StatefulWidget {
  const NotifierBuilder({this.notifier, required this.builder, super.key});

  final Listenable? notifier;
  final Widget Function(BuildContext context) builder;

  @override
  State<NotifierBuilder> createState() => _NotifierBuilderState();
}

class _NotifierBuilderState extends State<NotifierBuilder> {
  @override
  void initState() {
    super.initState();
    widget.notifier?.addListener(_handleChange);
  }

  @override
  void didUpdateWidget(NotifierBuilder oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.notifier != oldWidget.notifier) {
      oldWidget.notifier?.removeListener(_handleChange);
      widget.notifier?.addListener(_handleChange);
    }
  }

  @override
  void dispose() {
    widget.notifier?.removeListener(_handleChange);
    super.dispose();
  }

  void _handleChange() {
    setState(() {
      // The listenable's state is our build state, and it changed already.
    });
  }

  @override
  Widget build(BuildContext context) {
    return widget.builder(context);
  }
}
