import 'package:flutter/material.dart';

class NSlider extends StatelessWidget {
  const NSlider({
    super.key,
    this.sliderHeight = 4.0,
    this.thumbRadius = 8.0,
    this.overlayRadius = 16.0,
    this.thumbColor = Colors.white,
    this.overlayColor = Colors.white,
    this.activeColor = const Color(0xFFFFAB3F),
    this.inactiveColor = Colors.grey,
    this.min,
    required this.value,
    this.max,
    required this.onChanged,
  });

  final double? min;
  final double value;
  final double? max;

  final Function(double) onChanged;

  final double? sliderHeight;

  final Color? thumbColor;
  final double? thumbRadius;

  final Color? overlayColor;
  final double? overlayRadius;

  final Color? activeColor;
  final Color? inactiveColor;

  @override
  Widget build(BuildContext context) {
    return SliderTheme(
      data: SliderTheme.of(context).copyWith(
        trackHeight: sliderHeight,
        thumbShape: RoundSliderThumbShape(enabledThumbRadius: thumbRadius!),
        overlayShape: RoundSliderOverlayShape(overlayRadius: overlayRadius!),
      ),
      child: Slider(
        min: min ?? 0.0,
        value: value,
        max: max ?? 1.0,
        onChanged: onChanged,
        inactiveColor: inactiveColor?.withOpacity(0.3),
        thumbColor: thumbColor,
        activeColor: activeColor,
        overlayColor: MaterialStatePropertyAll(overlayColor?.withOpacity(0.4)),
      ),
    );
  }
}
